==> devextreme-22.1.1-alpha-21357-0315.tgz: package/cjs/renovation/component_wrapper/scheduler/group_panel.js <==
/**
 * DevExtreme (cjs/renovation/component_wrapper/scheduler/group_panel.js)
 * Version: 22.1.0 (build 21357-0315)
 * Build date: Thu Dec 23 2021
 *
 * Copyright (c) 2012 - 2021 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.GroupPanelWrapper = void 0;
var _component = _interopRequireDefault(require("../common/component"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _extends() {
    _extends = Object.assign || function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var GroupPanelWrapper = function(_Component) {
    _inheritsLoose(GroupPanelWrapper, _Component);

    function GroupPanelWrapper() {
        return _Component.apply(this, arguments) || this
    }
    var _proto = GroupPanelWrapper.prototype;
    _proto._setOptionsByReference = function() {
        _Component.prototype._setOptionsByReference.call(this);
        this._optionsByReference = _extends({}, this._optionsByReference, {
            resourceCellTemplate: true
        })
    };
    return GroupPanelWrapper
}(_component.default);
exports.GroupPanelWrapper = GroupPanelWrapper;

==> devextreme-22.2.1-alpha-22245-0308.tgz: package/cjs/renovation/component_wrapper/scheduler/group_panel.js <==
/**
 * DevExtreme (cjs/renovation/component_wrapper/scheduler/group_panel.js)
 * Version: 22.2.0 (build 22245-0308)
 * Build date: Fri Sep 02 2022
 *
 * Copyright (c) 2012 - 2022 Developer Express Inc. ALL RIGHTS RESERVED
 * Read about DevExtreme licensing here: https://js.devexpress.com/Licensing/
 */
"use strict";
exports.GroupPanelWrapper = void 0;
var _component = _interopRequireDefault(require("../common/component"));

function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
        default: obj
    }
}

function _extends() {
    _extends = Object.assign ? Object.assign.bind() : function(target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];
            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key]
                }
            }
        }
        return target
    };
    return _extends.apply(this, arguments)
}

function _inheritsLoose(subClass, superClass) {
    subClass.prototype = Object.create(superClass.prototype);
    subClass.prototype.constructor = subClass;
    _setPrototypeOf(subClass, superClass)
}

function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf ? Object.setPrototypeOf.bind() : function(o, p) {
        o.__proto__ = p;
        return o
    };
    return _setPrototypeOf(o, p)
}
var GroupPanelWrapper = function(_Component) {
    _inheritsLoose(GroupPanelWrapper, _Component);

    function GroupPanelWrapper() {
        return _Component.apply(this, arguments) || this
    }
    var _proto = GroupPanelWrapper.prototype;
    _proto._setOptionsByReference = function() {
        _Component.prototype._setOptionsByReference.call(this);
        this._optionsByReference = _extends({}, this._optionsByReference, {
            resourceCellTemplate: true
        })
    };
    return GroupPanelWrapper
}(_component.default);
exports.GroupPanelWrapper = GroupPanelWrapper;
